@@ -1,6 +1,7 @@
 package YAML::Any;
 
-use 5.005003;
+our $VERSION = '0.79';
+
 use strict;
 use Exporter ();
 
